Checkout

Struct Checkout 

pub struct Checkout<'a> {
    pub commit: &'a Commit,
    pub entries: HashMap<String, DirEntry<'a>>,
}
Commit reference with all entries collected from the repo.

Fields

commit: &'a Commitentries: HashMap<String, DirEntry<'a>>

Implementations

Source

impl<'a> Checkout<'a>

pub fn from_pack( pack: &'a HashMap<String, Object>, oid: &str, ) -> Result<Self, Error>

Collect checkout from a repository of objects.

Errors

Returns an error when an object cannot be found.

pub fn get_diff(&self, other: &Checkout<'_>) -> Vec<BlobDiff>

Get difference between checkouts.