ParcelEncoder

Struct ParcelEncoder 

pub struct ParcelEncoder<W: Write> { /* private fields */ }

Implementations

Source

impl<W: Write> ParcelEncoder<W>

pub fn new(writer: W) -> Self

pub fn write_data(&mut self, data: &[u8]) -> Result<(), Error>

Write a data packet to the output stream.

Errors

Returns an error when data packet size exceeds 65531, or when cannot write the data to the writer.

pub fn new_section(&mut self) -> Result<(), Error>

Writes a section separator marker to the output stream.

Errors

Returns an error when cannot write data to the writer.

pub fn finish(self) -> Result<(), Error>

Writes a stream end marker to the output stream.

Errors

Returns an error when cannot write data to the writer.