pub struct ParcelEncoder<W: Write> { /* private fields */ }Implementations
Sourceimpl<W: Write> ParcelEncoder<W>
impl<W: Write> ParcelEncoder<W>
pub fn new(writer: W) -> Self
Sourcepub fn write_data(&mut self, data: &[u8]) -> Result<(), Error>
pub fn write_data(&mut self, data: &[u8]) -> Result<(), Error>
Write a data packet to the output stream.
Errors
Returns an error when data packet size exceeds 65531, or when cannot write the data to the writer.